<?php
/**
 * The main template file for all pages
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package Starter_One
 */

get_header(); ?>

	<div id="primary" class="content-area">
		<main id="main" <?php post_class(); ?> role="main">
			
			<!-- TITLE -->
			<?php
				global $post;

				if(class_exists('acf')){
					$default_bg = get_field('op_default_bg','option');
					$default_bg_pos = get_field('op_default_bg_pos','option');
					$page_bg_img = get_field('pg_bg_img');
					$page_bg_pos = get_field('pg_bg_pos');
					$pg_hide_title = get_field('pg_hide_title');
					$pg_sm_title = get_field('pg_sm_title');
				}

				if ($page_bg_img){
					$bgimg = $page_bg_img;
					$bgimg_pos = $page_bg_pos;
				}else{
					$bgimg = $default_bg;
					$bgimg_pos = $default_bg_pos;
				}
				
				$parent_page = $post->post_parent;
				if($parent_page && $post->id != $parent_page){
					$breadcrumb_url = get_the_permalink($parent_page);
					$breadcrumb_name = get_the_title($parent_page);
				}
				
				$title = get_the_title();
			
				?>

				<div class="title-wrap wrapper level " style="<?php if($pg_hide_title == true){ echo 'display:none!important; '; }else{ if($bgimg){echo 'background-image:url('.$bgimg.'); background-position: center '.$bgimg_pos.'%!important;';}}
				if($pg_sm_title == true){ echo 'min-height:0!important;';}?>">

					<div class="grid-container container columns">
						<?php //Get Titles
							include(locate_template('/template-parts/content/title-home.php'));
						?>
					</div><!-- .grid-container-->
				</div><!-- .wrapper -->


			<!-- CONTENT -->
			<div class="content-wrap wrapper  <?php if($pg_hide_title){ echo 'no-title-padding-top';}?>">
				<div class="grid-container container columns">
					
					<div class="main-content column">
						
						<?php // Latest Posts Loop
						get_template_part( 'template-parts/loops/loop', 'latest-posts-home' );
						?>
						
						<?php // CTA and Form
						if(class_exists('acf')){
							 if( have_rows('call_to_action_form') ): while( have_rows('call_to_action_form') ): the_row(); 
								$home_cta_heading = get_sub_field('home_cta_heading');
								$home_cta_content = get_sub_field('home_cta_content');
								$home_cta_form = get_sub_field('home_cta_form');
							endwhile; endif;
						}
						?>
						
						<div class="columns full-width-band home-cta-form white">
						
							<div class="column">
								<h2><?php echo $home_cta_heading;?></h2>
								<p><?php echo $home_cta_content;?></p>
							</div>
							
							<div class="column">
								<?php echo do_shortcode('[contact-form-7 id="'.$home_cta_form.'"]');?>
							</div>
						
						</div><!-- .home-cta-form-->

						<?php // CPT Grid 
						
						?>
						<div class="columns home-cpt-grid">
							
							<div class="column">
								
								<?php // Loops
						
								if(class_exists('acf')){
									 if( have_rows('home_cat_grid') ): while( have_rows('home_cat_grid') ): the_row(); 
										$first_row_cat  = get_sub_field('first_row_cat');
										$second_row_cat = get_sub_field('second_row_cat');
									endwhile; endif;
								}
						
									// First Loop
									include(locate_template( 'template-parts/loops/loop-reports-home.php' ));
									// Second Loop
									include(locate_template( 'template-parts/loops/loop-cat-second-home.php' ));
								?>
							</div>
							
							
						
						</div>
						
					</div><!-- .main-content-->
					

				</div><!-- .grid-container-->
			</div><!-- .wrapper -->


		</main><!-- #main -->
	</div><!-- #primary -->

<?php
get_footer();
