<?php
/**
 * The main template file for single post types
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package Starter_One
 */

get_header(); 

$is_extended_report  = get_field('extended_report');
$extended_post_class = ($is_extended_report ) ? 'extended-report' : '';
?>

<div id="primary" class="content-area">
	<main id="main" <?php post_class($extended_post_class ); ?> role="main">
		
		<?php
			global $post;
		
			$post_type = get_post_type();
			$post_id = get_the_ID();
			
			//Breadcrumbs
			$cpt_obj = get_queried_object();
			$cpt_post_type = $cpt_obj->post_type;
			$breadcrumb_url = get_post_type_archive_link($cpt_post_type);
			$post_type_obj = get_post_type_object( $cpt_post_type);
			$breadcrumb_name = $post_type_obj->labels->name;
			
				
			$title = get_the_title();
		
			//Extended Report
			if($is_extended_report ){ 
		
				$page_bg_img = get_field('pg_bg_img');
				$page_bg_pos_v = get_field('pg_bg_pos');
				$pg_display_title = get_field('pg_display_title');
				$pg_title_tagline = get_field('pg_title_tagline'	);
		
				$inline_bg_style = 'background-image:url('.$page_bg_img['sizes']['large'].'); background-position: 50% '.$page_bg_pos_v.'%!important;';
			} ?>
			<!-- TITLE -->
		<div class="title-wrap wrapper level " style="<?php if(!empty($page_bg_img) ){ echo $inline_bg_style;  } ?>">
			
			<div class="grid-container container columns">
				<?php //Get Titles
					if($is_extended_report ){
						include(locate_template('/template-parts/content/title.php'));
					} else { 
						include(locate_template('/template-parts/content/title-single.php'));
					}
				?>
			</div><!-- .grid-container-->
		</div><!-- .wrapper -->


		<!-- CONTENT -->
		<div class="content-wrap wrapper <?php if(isset($pg_hide_title) && $pg_hide_title){ echo 'no-title-padding-top';}?>">
			<div class="grid-container container columns">
				
				<div class="main-content column">
					
					<?php // Content	

					while ( have_posts() ) : the_post();
							
							if($is_extended_report ){
								include(locate_template('/template-parts/content/content-extended-report.php'));
							} else { 
								include(locate_template('/template-parts/content/content.php'));
							}
							
					
						//Related Posts
						include(locate_template('/template-parts/partials/related-posts.php'));
						
					
					endwhile; // End of the loop.
					
					?>
					
				</div><!-- .main-content-->

			</div><!-- .grid-container-->
		</div><!-- .wrapper -->

	</main><!-- #main -->
</div><!-- #primary -->

<?php
get_footer();