<?php
/**
 * The main template file for single post types
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package Starter_One
 */

get_header(); ?>

<div id="primary" class="content-area">
	<main id="main" <?php post_class(); ?> role="main">
		
		<?php
			global $post;
		
			$post_types = array('post','story','multimedia','report');
			$post_type = get_post_type();
			
			$post_id = get_the_ID();

			if ( 'post' === $post_type ){
				$categories = get_the_category( $post_id );
				$category_id = $categories[0]->cat_ID;
			}
		
			//Title and Breadcrumbs
			if(is_singular('post')){
			
				$post_categories = get_the_category();
				$breadcrumb_url = get_category_link($post_categories[0]->term_id);
				$breadcrumb_name  = $post_categories[0]->name;
			
			} elseif(is_singular('multimedia')){
				
				$mm_page_id = custom_get_page_id_by_template('template-multimedia-archive.php');
				$breadcrumb_url = get_the_permalink($mm_page_id);
				$breadcrumb_name  = get_the_title($mm_page_id);
				
			} else {
				
				$cpt_obj = get_queried_object();
				$cpt_post_type = $cpt_obj->post_type;
				$breadcrumb_url = get_post_type_archive_link($cpt_post_type);
				$post_type_obj = get_post_type_object( $cpt_post_type);
				$breadcrumb_name = $post_type_obj->labels->name;
			}
				
			$title = get_the_title();
				
			//Video / Gallery
			$display_video = get_field('post_include_video');
			$display_gallery = get_field('post_include_gallery');
		
			?>
			
		<!-- TITLE -->
		<div class="title-wrap wrapper level " style="<?php if(isset($pg_hide_title) && $pg_hide_title == true){ echo 'display:none!important; '; }
		if(isset($pg_sm_title) && $pg_sm_title == true){ echo 'min-height:0!important;';}?>">
			
			<div class="grid-container container columns">
				<?php //Get Titles
					include(locate_template('/template-parts/content/title-single.php'));
				?>
			</div><!-- .grid-container-->
		</div><!-- .wrapper -->


		<!-- CONTENT -->
		<div class="content-wrap wrapper <?php if(isset($pg_hide_title) && $pg_hide_title){ echo 'no-title-padding-top';}?>">
			<div class="grid-container container columns">
				
				<div class="main-content column">
					
					<?php // Content	

					while ( have_posts() ) : the_post();
							
							if('report' == get_post_type() && get_field('extended_report') == true){
								include(locate_template('/template-parts/content/content-extend-report.php'));
							} else { 
								include(locate_template('/template-parts/content/content.php'));
							}
							
					
						
						if(is_singular('post')){
							// If comments are open or we have at least one comment, load up the comment template.
							if ( comments_open() || get_comments_number() ) :
							//	comments_template();
							endif;
						}

						//Related Posts
						include(locate_template('/template-parts/partials/related-posts.php'));
						
						// Stories CTA
						if('story' == get_post_type()){
							include(locate_template( 'template-parts/partials/stories-cta.php' ));
						}
					
					endwhile; // End of the loop.
					
					?>
					
				</div><!-- .main-content-->

			</div><!-- .grid-container-->
		</div><!-- .wrapper -->

	</main><!-- #main -->
</div><!-- #primary -->

<?php
get_footer();