<?php
/**
 * Template name: Multimedia Archive Page
 *	The template for displaying archive pages
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package Starter_One
 */

get_header(); ?>

<div id="primary" class="content-area">
	<main id="main" class="site-main multimedia-archive-page" role="main">

	<?php
		global $post, $paged;
		
		
		if(class_exists('acf')){
			//default title
			$default_bg = get_field('op_default_bg','option');
			$default_bg_pos = get_field('op_default_bg_pos','option');
			
			//inherited title
			$media_type = 'multimedia';
			$title_inheritace_settings = get_field('inherit_page_title','option');
			foreach ($title_inheritace_settings as $inheritance){
				if($inheritance['archive_type'] == $media_type) {
					$inherit_pg_id = $inheritance['pg_title_to_display'];
				} else {
					continue;
				}
			}
			
			//If page inherits title, use inherited page settings
			if($inherit_pg_id ){
				$pg_id = $inherit_pg_id;
			} else {
				$pg_id = get_the_id();
			}
				
			$inherit_bg_img = get_field('pg_bg_img', $pg_id);
			$inherit_bg_pos = get_field('pg_bg_pos', $pg_id);
			$pg_hide_overlay = get_field('pg_hide_overlay', $pg_id);
			$pg_hide_title = get_field('pg_hide_title', $pg_id);
			
			$pg_display_title = get_field('pg_display_title',$pg_id);
			$pg_title_tagline = get_field('pg_title_tagline'	,$pg_id);
				
			//Content padding
			$pg_no_top_padding = get_field('pg_no_top_padding');
			$pg_no_bottom_padding = get_field('pg_no_bottom_padding');	
		}
		
		//Title Image
		if($inherit_bg_img){
			$bgimg = $inherit_bg_img;
			$bgimg_pos = $inherit_bg_pos;
		}elseif ($page_bg_img){
			$bgimg = $page_bg_img;
			$bgimg_pos = $page_bg_pos;
		}else{
			$bgimg = $default_bg;
			$bgimg_pos = $default_bg_pos;
		}
		
		$inline_bg_style = 'background-image:url('.$bgimg.')!important; background-position: center '.$bgimg_pos.'%!important;';
			
		$title = get_the_title();
	
	?>
	<!--TITLE-->
	<div class="title-wrap wrapper level <?php if($pg_hide_overlay){echo ' no-overlay ';}?>" style="<?php if($pg_hide_title == true){ echo 'display:none!important; '; }else{ if($bgimg){echo $inline_bg_style;}}
		if($pg_sm_title == true){ echo 'min-height:0!important;';}?>">
		<div class="grid-container container columns">
			
			<?php //Get Titles
				include(locate_template('/template-parts/content/title.php'));
			?>

		</div><!-- .grid-container-->
	</div><!-- .wrapper -->
	
	<!-- CONTENT-->
	<div class="content-wrap wrapper <?php if($pg_hide_title){ echo 'no-title-padding-top ';} if($pg_no_top_padding){ echo 'no-top-padding ';} if($pg_no_bottom_padding){ echo 'no-bottom-padding ';}?>">
			
		<div class="grid-container container columns">

			<div class="main-content column columns is-multiline">

				<?php // Content
					
					$q_post_types = array('post','story','multimedia');
					$q_categories = array('photo-essays','infographics');

					// Get posts by category
					$arg1 = array(
						'fields'         => 'ids',
						'post_type'   => 'post',
						'post_status' => 'publish',
						'posts_per_page' => -1,
						'ignore_sticky_posts' => 1,
						'numberposts' => -1,
						'tax_query' => array(
							array(
								'taxonomy' => 'category',
								'field'    => 'slug',
								'terms'    => $q_categories,
							),
						),
					);
					
					//Get posts by meta
					$arg2 = array(
						'fields'         => 'ids',
						'post_type'   => $q_post_types,
						'post_status' => 'publish',
						'posts_per_page' => -1,
						'ignore_sticky_posts' => 1,
						'numberposts' => -1,
						'meta_query' => array(
							array(
								'key' => 'post_include_video',
								'value'    => true,
								'compare'    => '=',
							),
						),
					);

					//Combine Queries
					$query1 = new WP_Query($arg1);
					$query2 = new WP_Query($arg2);

					$q_post_ids = array_merge( $query1->posts, $query2->posts);

					// Create combined query, in order
					$query = new WP_Query(array(
						'post_type' => $q_post_types,
						'post__in'  => $q_post_ids, 
						 'paged' => $paged,
						'orderby'   => 'date', 
						'order'     => 'DESC',
						'posts_per_page' => 10,
						'ignore_sticky_posts' => 1,
						'numberposts' => -1,
					));

					

					// Pagination fix
					$temp_query = $wp_query;
					$wp_query   = NULL;
					$wp_query   = $query;
					
					// we also need to set post count correctly so as to enable the looping
					$query->post_count = count( $query->posts );
					
					if ($query->have_posts() ) : 
						/* Start the Loop */
						
						while ( $query->have_posts() ) : $query->the_post();
							include(locate_template('/template-parts/content/content-grid.php'));
						endwhile;

					else :

						get_template_part( 'template-parts/content/content', 'none' );

					endif; 
								
					get_template_part( 'template-parts/content/pagination');
					
					wp_reset_postdata();
					// Reset main query object
					$wp_query = NULL;
					$wp_query = $temp_query;
				?>
					
			</div><!-- .main-content-->

		</div><!-- .grid-container-->
	</div><!-- .wrapper -->
		
	</main><!-- #main -->
</div><!-- #primary -->

<?php
get_footer();
